==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/cannons/dialogs_de.lua <==

dialogId("del-v-dve", "font_big", "See? This ship had two gun decks. It must have been a man-of-war. The acrid smell of gunpowder still seems to linger in the air...")
dialogStr("Siehst du? Dieses Schiff hatte zwei Kanonendecks. Es muss ein Kriegsschiff gewesen sein. Der beißende Geruch von Schießpulver scheint noch in der Luft zu liegen...")


dialogId("del-m-voda", "font_small", "You mean, in the water.")
dialogStr("Du meinst \"im Wasser\".")


dialogId("del-m-ci", "font_small", "Whose ship was she? Maybe she served under admiral Nelson... or captain Hornblower.")
dialogStr("Wessen Schiff war das? Vielleicht diente es unter Admiral Nelson... oder Kapitän Hornblower.")


dialogId("del-v-splet", "font_big", "No, I think you`re about a hundred years off.")
dialogStr("Nein. Ich glaube, du liegst ungefähr einhundert Jahre daneben.")


dialogId("del-v-mec", "font_big", "I have a feeling we`re going to need that sword.")
dialogStr("Ich hab das Gefühl, wir werden das Schwert brauchen.")


dialogId("del-m-tus", "font_small", "You and your 'feelings`. Besides, we`re not supposed to be giving any hints.")
dialogStr("Du und deine \"Gefühle\". Außerdem sollen wir keine Tipps geben.")


dialogId("del-m-jedn0", "font_small", "That was a little too simple, wasn`t it?")
dialogStr("Das war ein bisschen zu einfach, oder?")


dialogId("del-m-jedn1", "font_small", "Could it possibly be so simple?")
dialogStr("Kann es wirklich so einfach sein?")


dialogId("del-m-jedn2", "font_small", "There must be some kind of mistake.")
dialogStr("Da muss irgendwo ein Fehler sein.")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/cannons/dialogs_de.lua <==

dialogId("del-v-dve", "font_big", "See? This ship had two gun decks. It must have been a man-of-war. The acrid smell of gunpowder still seems to linger in the air...")
dialogStr("Siehst du? Dieses Schiff hatte zwei Kanonendecks. Es muss ein Kriegsschiff gewesen sein. Der beißende Geruch von Schießpulver scheint noch in der Luft zu liegen...")


dialogId("del-m-voda", "font_small", "You mean, in the water.")
dialogStr("Du meinst \"im Wasser\".")


dialogId("del-m-ci", "font_small", "Whose ship was she? Maybe she served under admiral Nelson... or captain Hornblower.")
dialogStr("Wessen Schiff war das? Vielleicht diente es unter Admiral Nelson... oder Kapitän Hornblower.")


dialogId("del-v-splet", "font_big", "No, I think you’re about a hundred years off.")
dialogStr("Nein. Ich glaube, du liegst ungefähr einhundert Jahre daneben.")


dialogId("del-v-mec", "font_big", "I have a feeling we’re going to need that sword.")
dialogStr("Ich hab das Gefühl, wir werden das Schwert brauchen.")


dialogId("del-m-tus", "font_small", "You and your 'feelings’. Besides, we’re not supposed to be giving any hints.")
dialogStr("Du und deine \"Gefühle\". Außerdem sollen wir keine Tipps geben.")


dialogId("del-m-jedn0", "font_small", "That was a little too simple, wasn’t it?")
dialogStr("Das war ein bisschen zu einfach, oder?")


dialogId("del-m-jedn1", "font_small", "Could it possibly be so simple?")
dialogStr("Kann es wirklich so einfach sein?")


dialogId("del-m-jedn2", "font_small", "There must be some kind of mistake.")
dialogStr("Da muss irgendwo ein Fehler sein.")
